/* Last modified: January 20, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: estout - available from within Stata by typing "ssc install estout" or at http://repec.org/bocode/e/estout/esttab.html
                 xtabond2 - - available from within Stata by typing "ssc install xtabond2" 
		 (Note: the xtabond2 command as we use it may not function properly on versions of Stata older than Stata 13)
	      
Files needed: 

bds.dta - a cleaned version of the Business Dyanamics Statistics, linked to State minimum wage data and other covariates

*/


*------------------------------*
*    MONTE CARLO SIMULATION    *
*------------------------------*

/* 	    WARNING: 

	    This is currently set up to run 10,000 Monte Carlo repetitions, which can take a while, especially the A-B estimations.
            You can change this setting just below this message. We used 10,000 repetitions in the article. 
*/

clear all
set more off

local repetitions = 10000  // Set this: total MC repetitions
local notify = 5 // Set this: How often to notify, measured in number of reps.
local seed = 0 // Can set this if desired

set seed `seed'

* cd "working directory" // Change this to the directory with the bds.dta file

**************************
* Define several programs:
**************************

*******************************
* [1] One-Time Preparation    *
*******************************

program define prep
*******

use bds.dta, clear
keep statefip year lnmin mw lemp
gen demp = F1.lemp - lemp
gen lmw = ln(mw)
gen dmw = F1.lmw - lmw
replace dmw = 0 if dmw <= 0 | dmw == .

drop if demp == . // i.e. 2011
keep demp dmw
save realchanges.dta , replace

use bds.dta , clear
keep year lemp
replace lemp = . if year != 1977
rename lemp emp
replace year = year - 1976
rename year period
sort period
gen id = (_n - floor( (period-1) * 51))
xtset id period
sort id period
compress
order id period
gen crosswalk = _n
save panel , replace

*******
end

*******************************
* [2] Data Generating Process *
*******************************

program define dgp
*******

use realchanges , clear
gen randnum = uniform()
sort randnum
gen crosswalk = _n
keep crosswalk demp
save tempdemp.dta , replace
use realchanges , clear
gen randnum = uniform()
sort randnum
gen crosswalk = _n
keep crosswalk dmw
save tempdmw.dta , replace

use panel , clear
merge 1:1 crosswalk using tempdemp
drop _merge
merge 1:1 crosswalk using tempdmw
drop _merge crosswalk
erase tempdemp.dta
erase tempdmw.dta
sort id period
xtset id period
replace emp = emp[_n-1] + demp if period >= 2 & emp == .
gen mw = dmw if period == 1
replace mw = mw[_n-1 ] + dmw if period >= 2 & mw == .

*******
end

*******************************
* [3] Impose the Treatment    *
*******************************

program define treatment
*******

local trendcorr = 0  // Direction of correlation for MW regime and employment trends. Values: {-1,0,1}

/* ORIGINAL SIMULATED EFFECT FROM PAPER: (Changed to 0.03 from 0.05) */
gen phi = rnormal(0.03 , 0.015)

* CAN CHANGE TO SHOW THAT INCORPORATING INLFATION DOESN'T AFFECT SIMULATION RESULTS:
gen inflation = 0 // rnormal(0.04,0.03) or whatever you'd like
rename mw nommw
gen mw = nommw if period == 1
replace mw = mw[_n-1] + dmw - inflation if period > 1
gen alpha = -1 * mw * phi
gen newdemp = demp + alpha
gen newemp = emp if period == 1
replace newemp = newemp[_n-1] + newdemp if period >= 2 & newemp == .

* Induce correlation between jurisdiction MW and employment trends (direction set at top of code above):

if `trendcorr' != 0 {
egen temp = mean(mw) , by(id)
egen temp2 = median(temp)
gen highlow = (temp > temp2)
replace newemp = newemp + `trendcorr' * 0.015 * period * highlow
}

*******
end

*******************************
* [4] Run the Regressions     *
*******************************

program define regressions
*******

estimates clear

* Without jurisdiction-specific time trends:

qui xtreg newemp mw i.period , fe r cluster(id)
estimates store col1

qui xtreg newemp L(0/3).mw i.period , fe r cluster(id)
estimates store col2

qui reg D.newemp DL(0/3).mw i.period , r cluster(id)
estimates store col3

qui xtabond2 newemp L.newemp L(0/1).mw i.period, gmm(mw) iv(L.newemp i.period) nolevel robust
estimates store col4

qui reg D.newemp mw i.period , r cluster(id)
estimates store col5

* With jurisdiction-specific time trends:

qui xtreg newemp mw i.period i.id#c.period , fe r cluster(id)
estimates store col1b

qui xtreg newemp L(0/3).mw i.period i.id#c.period , fe r cluster(id)
estimates store col2b

qui xtreg D.newemp DL(0/3).mw i.period , fe r cluster(id)
estimates store col3b

qui xtabond2 newemp L.newemp L(0/1).mw i.period i.id#c.period , gmm(mw) iv(L.newemp i.period i.id#c.period) nolevel robust
estimates store col4b

qui xtreg D.newemp mw i.period , fe r cluster(id)
estimates store col5b

*******
end

*******************************
* [5] Evaluate Trend Corr.    *
*******************************

program define trendcorr
*******

qui egen msmw = mean(mw) , by(id)
qui reg D.newemp mw i.period
qui predict xb
qui gen resid = D.newemp - xb
qui collapse (mean) mw resid , by(id)
qui estpost corr mw resid
qui estimates store correst

*******
end


**************************
* Run the repetitions:
**************************

qui prep
qui dgp
qui treatment
qui regressions
qui trendcorr
qui esttab correst using 0_corr_mwregime_trends.csv , replace noobs nostar nonum nomtitles nonote not
qui esttab col1 using 1_classic.csv , replace keep(mw) noobs nostar nonum nomtitles nonote not
qui esttab col2 using 2_dist_lags_levels.csv , replace keep(mw L*.mw) noobs nostar nonum nomtitles nonote not
qui esttab col3 using 3_dist_lags_fd.csv , replace keep(D.mw L*.mw) noobs nostar nonum nomtitles nonote not
qui esttab col4 using 4_dynamic_panel.csv , replace keep(L.newemp mw L*.mw) noobs nostar nonum nomtitles nonote not
qui esttab col5 using 5_break_in_trend.csv , replace keep(mw) noobs nostar nonum nomtitles nonote not
qui esttab col1b using 1b_classic.csv , replace keep(mw) noobs nostar nonum nomtitles nonote not
qui esttab col2b using 2b_dist_lags_levels.csv , replace keep(mw L*.mw) noobs nostar nonum nomtitles nonote not
qui esttab col3b using 3b_dist_lags_fd.csv , replace keep(D.mw L*.mw) noobs nostar nonum nomtitles nonote not
qui esttab col4b using 4b_dynamic_panel.csv , replace keep(L.newemp mw L*.mw) noobs nostar nonum nomtitles nonote not
qui esttab col5b using 5b_break_in_trend.csv , replace keep(mw) noobs nostar nonum nomtitles nonote not

forvalues r = 2/`repetitions' {
qui prep
qui dgp
qui treatment
qui regressions
qui trendcorr
qui esttab correst using 0_corr_mwregime_trends.csv , append noobs nostar nonum nomtitles nonote not
qui esttab col1 using 1_classic.csv , append keep(mw) noobs nostar nonum nomtitles nonote not
qui esttab col2 using 2_dist_lags_levels.csv , append keep(mw L*.mw) noobs nostar nonum nomtitles nonote not
qui esttab col3 using 3_dist_lags_fd.csv , append keep(D.mw L*.mw) noobs nostar nonum nomtitles nonote not
qui esttab col4 using 4_dynamic_panel.csv , append keep(L.newemp mw L*.mw) noobs nostar nonum nomtitles nonote not
qui esttab col5 using 5_break_in_trend.csv , append keep(mw) noobs nostar nonum nomtitles nonote not
qui esttab col1b using 1b_classic.csv , append keep(mw) noobs nostar nonum nomtitles nonote not
qui esttab col2b using 2b_dist_lags_levels.csv , append keep(mw L*.mw) noobs nostar nonum nomtitles nonote not
qui esttab col3b using 3b_dist_lags_fd.csv , append keep(D.mw L*.mw) noobs nostar nonum nomtitles nonote not
qui esttab col4b using 4b_dynamic_panel.csv , append keep(L.newemp mw L*.mw) noobs nostar nonum nomtitles nonote not
qui esttab col5b using 5b_break_in_trend.csv , append keep(mw) noobs nostar nonum nomtitles nonote not

if floor(`r'/`notify') + 0.001 > `r'/`notify' & floor(`r'/`notify') - 0.001 < `r'/`notify' { // e.g. every ten reps. - set above
display "`r' repetitions completed" 
}
}

erase panel.dta
erase realchanges.dta

**************************
* Compile the results:
**************************

insheet using 1_classic.csv , comma clear
gen coef = 0
gen mean = v2
gen median = v2
gen p5 = v2
gen p95 = v2
collapse (mean) mean (median) median (p5) p5 (p95) p95 , by(coef)
gen model = 1
gen model_name = "Classic"
gen trends = "No"
order model model_name trends
order model model_name
sort model trends coef
save summary_results.dta , replace

insheet using 2_dist_lags_levels.csv , comma clear
gen coef = 0 if v1 == "mw"
replace coef = 1 if v1 == "L.mw"
replace coef = 2 if v1 == "L2.mw"
replace coef = 3 if v1 == "L3.mw"
gen mean = v2
gen median = v2
gen p5 = v2
gen p95 = v2
collapse (mean) mean (median) median (p5) p5 (p95) p95 , by(coef)
gen model = 2
gen model_name = "Dist Lag Levels"
gen trends = "No"
order model model_name trends
append using summary_results.dta
sort model trends coef
save summary_results.dta , replace

insheet using 3_dist_lags_fd.csv , comma clear
gen coef = 0 if v1 == "D.mw"
replace coef = 1 if v1 == "LD.mw"
replace coef = 2 if v1 == "L2D.mw"
replace coef = 3 if v1 == "L3D.mw"
gen mean = v2
gen median = v2
gen p5 = v2
gen p95 = v2
collapse (mean) mean (median) median (p5) p5 (p95) p95 , by(coef)
gen model = 3
gen model_name = "Dist Lag FD"
gen trends = "No"
order model model_name trends
append using summary_results.dta
sort model trends coef
save summary_results.dta , replace

insheet using 4_dynamic_panel.csv , comma clear
gen coef = 0 if v1 == "mw"
replace coef = 1 if v1 == "L.mw"
replace coef = 2 if v1 == "L2.mw"
replace coef = 3 if v1 == "L3.mw"
replace coef = -99 if v1 == "L.newemp"
gen mean = v2
gen median = v2
gen p5 = v2
gen p95 = v2
collapse (mean) mean (median) median (p5) p5 (p95) p95 , by(coef)
gen model = 4
gen model_name = "Dynamic Panel"
gen trends = "No"
order model model_name trends
append using summary_results.dta
sort model trends coef
save summary_results.dta , replace

insheet using 5_break_in_trend.csv , comma clear
gen coef = 0
gen mean = v2
gen median = v2
gen p5 = v2
gen p95 = v2
collapse (mean) mean (median) median (p5) p5 (p95) p95 , by(coef)
gen model = 5
gen model_name = "Break in Trend"
gen trends = "No"
order model model_name trends
append using summary_results.dta
sort model trends coef
save summary_results.dta , replace

****

insheet using 1b_classic.csv , comma clear
gen coef = 0
gen mean = v2
gen median = v2
gen p5 = v2
gen p95 = v2
collapse (mean) mean (median) median (p5) p5 (p95) p95 , by(coef)
gen model = 1
gen model_name = "Classic"
gen trends = "Yes"
order model model_name trends
order model model_name
append using summary_results.dta
sort model trends coef
save summary_results.dta , replace

insheet using 2b_dist_lags_levels.csv , comma clear
gen coef = 0 if v1 == "mw"
replace coef = 1 if v1 == "L.mw"
replace coef = 2 if v1 == "L2.mw"
replace coef = 3 if v1 == "L3.mw"
gen mean = v2
gen median = v2
gen p5 = v2
gen p95 = v2
collapse (mean) mean (median) median (p5) p5 (p95) p95 , by(coef)
gen model = 2
gen model_name = "Dist Lag Levels"
gen trends = "Yes"
order model model_name trends
append using summary_results.dta
sort model trends coef
save summary_results.dta , replace

insheet using 3b_dist_lags_fd.csv , comma clear
gen coef = 0 if v1 == "D.mw"
replace coef = 1 if v1 == "LD.mw"
replace coef = 2 if v1 == "L2D.mw"
replace coef = 3 if v1 == "L3D.mw"
gen mean = v2
gen median = v2
gen p5 = v2
gen p95 = v2
collapse (mean) mean (median) median (p5) p5 (p95) p95 , by(coef)
gen model = 3
gen model_name = "Dist Lag FD"
gen trends = "Yes"
order model model_name trends
append using summary_results.dta
sort model trends coef
save summary_results.dta , replace

insheet using 4b_dynamic_panel.csv , comma clear
gen coef = 0 if v1 == "mw"
replace coef = 1 if v1 == "L.mw"
replace coef = 2 if v1 == "L2.mw"
replace coef = 3 if v1 == "L3.mw"
replace coef = -99 if v1 == "L.newemp"
gen mean = v2
gen median = v2
gen p5 = v2
gen p95 = v2
collapse (mean) mean (median) median (p5) p5 (p95) p95 , by(coef)
gen model = 4
gen model_name = "Dynamic Panel"
gen trends = "Yes"
order model model_name trends
append using summary_results.dta
sort model trends coef
save summary_results.dta , replace

insheet using 5b_break_in_trend.csv , comma clear
gen coef = 0
gen mean = v2
gen median = v2
gen p5 = v2
gen p95 = v2
collapse (mean) mean (median) median (p5) p5 (p95) p95 , by(coef)
gen model = 5
gen model_name = "Break in Trend"
gen trends = "Yes"
order model model_name trends
append using summary_results.dta
sort model trends coef
save summary_results.dta , replace

insheet using 0_corr_mwregime_trends.csv , comma clear
gen coef = 0
gen mean = v2
gen median = v2
gen p5 = v2
gen p95 = v2
collapse (mean) mean (median) median (p5) p5 (p95) p95 , by(coef)
gen model = 0
gen model_name = "Trend Correlation"
gen trends = ""
replace coef = .
order model model_name trends
append using summary_results.dta
sort model trends coef
save summary_results.dta , replace

label define laglab -99 "L.emp" 0 "MW" 1 "L.MW" 2 "L2.MW" 3 "L3.MW"
label values coef laglab
erase summary_results.dta
outsheet using summary_results.csv , comma replace

*browse
